@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 #------------------------------------------------------------------------------
 # Read or write information in a PPM/PGM/PBM image
@@ -29,7 +29,7 @@ sub ProcessPPM($$)
     my $outfile = $$dirInfo{OutFile};
     my $verbose = $et->Options('Verbose');
     my $out = $et->Options('TextOut');
-    my ($buff, $num, $type, %info);
+    my ($buff, $num, $type, %info, $seal);
 #
 # read as much of the image as necessary to extract the header and comments
 #
@@ -77,6 +77,7 @@ sub ProcessPPM($$)
     if (defined $info{Comment}) {
         $info{Comment} =~ s/^# ?//mg;   # remove "# " at the start of each line
         $info{Comment} =~ s/[\n\r]+$//; # remove trailing newline
+        $seal = 1 if $info{Comment} =~ /^<seal seal=/;
     }
     $et->SetFileType($type);
     my $len = pos($buff);
@@ -91,6 +92,10 @@ sub ProcessPPM($$)
             ++$$et{CHANGED};
             $et->VerboseValue('- Comment', $oldComment) if defined $oldComment;
             $et->VerboseValue('+ Comment', $newComment) if defined $newComment;
+        } elsif ($seal and $$et{DEL_GROUP}{SEAL}) {
+            # delete SEAL comment
+            $et->VerboseValue('- Comment', $oldComment);
+            ++$$et{CHANGED};            
         } else {
             $newComment = $oldComment;  # use existing comment
         }
@@ -116,6 +121,10 @@ sub ProcessPPM($$)
         print $out "$type header ($len bytes):\n";
         $et->VerboseDump(\$buff, Len => $len);
     }
+    if ($seal) {
+        $et->ProcessDirectory({ DataPt => \$info{Comment} }, GetTagTable('Image::ExifTool::XMP::SEAL'));
+        delete $info{Comment};
+    }
     my $tag;
     foreach $tag (qw{Comment ImageWidth ImageHeight MaxVal}) {
         $et->FoundTag($tag, $info{$tag}) if defined $info{$tag};
@@ -143,7 +152,7 @@ BitMap) images.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
